#
# spec file for package cockpit-machines
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cockpit-machines
Version:        316
Release:        1.2
Summary:        Cockpit user interface for virtual machines
License:        LGPL-2.1-or-later AND MIT
URL:            https://github.com/cockpit-project/cockpit-machines
Source:         https://github.com/cockpit-project/cockpit-machines/archive/refs/tags/%{version}.tar.gz#/cockpit-machines-%{version}.tar.gz
Source10:       package-lock.json
Source11:       node_modules.spec.inc
Source12:       update_version.sh
%include %_sourcedir/node_modules.spec.inc
Patch10:        hide-docs.patch
Patch11:        load-css-overrides.patch
BuildArch:      noarch
BuildRequires:  appstream-glib
BuildRequires:  make
Requires:       cockpit-bridge >= 215
%if 0%{?suse_version}
Requires:       libvirt-daemon-qemu
%else
Requires:       libvirt-daemon-kvm
%endif
Requires:       libvirt-client
Requires:       libvirt-dbus >= 1.2.0
Requires:       qemu-spice
Requires:       virt-install
# Optional components
Recommends:     libosinfo
Recommends:     python3-gobject-base
#
BuildRequires:  cockpit-devel >= 293
BuildRequires:  local-npm-registry
BuildRequires:  sassc

%description
Cockpit component for managing virtual machines.

If "virt-install" is installed, you can also create new virtual machines.

%prep
%autosetup -p1
local-npm-registry %{_sourcedir} install --include=dev --ignore-scripts || ( find ~/.npm/_logs -name '*-debug.log' -print0 | xargs -0 cat; false)

%build
export PREFIX=%_prefix
mkdir -p pkg/lib
cp -r %{_datadir}/cockpit/devel/lib/* pkg/lib
NODE_ENV=production npm run build

%install
export PREFIX=%_prefix
%make_install
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/*

%files
%doc README.md
%license LICENSE
%{_datadir}/cockpit
%{_datadir}/metainfo/*

%changelog
* Wed Jul 31 2024 Adam Majer <adam.majer@suse.de>
- update_version.sh: add script for auto-updates
- switch to upstream package-lock.json
- do not run scripts during npm install
- switch to source package instead of precombined upstream release
* Mon Jul 15 2024 Luna D Dragon <luna.dragon@suse.com>
- Update to 316:
  * Bug fixes and performance improvements
- Changes from 315:
  * Translation updates and bug fixes
- Changes from 314:
  * Fix translation extraction
  * Translation updates
- Changes from 313:
  * Updates to translations
- Changes from 312:
  * Bug fixes and performance improvements
- Changes from 311:
  * Allow pasting multiple SSH keys at once in Create VM dialog
  * Fix detaching host device for running VMs
- Changes from 310:
  * Bug fixes and performance improvements
- Changes from 309:
  * bug fixes and performance improvements
- Changes from 308:
  * Add TPM when switching to EFI
  * Translation updates
  * Only use external snapshots for disks of type "file"
  * Skip empty media drives for external snapshots
  * Refresh VM after creating/reverting/deleting snapshots
  * Don't list disks in snapshot XML
  * Fix detaching host devices for running VMs
* Sun Feb 18 2024 ecsos <ecsos@opensuse.org>
- Update to 307:
  * Mass SPICE replacement
  * Pre-formatted Block Device storage pool support
- Changes from 306:
  * Machines: Action to Replace SPICE devices
  * Machines: Create external snapshots when supported
* Wed Jan 31 2024 Adam Majer <adam.majer@suse.de>
- Update to 305:
  * Avoid creating duplicate MACs
  * Fix page crash on invalid domain startup times
  * Other small fixes
* Fri Dec 29 2023 Adam Majer <adam.majer@suse.de> - 304
- Update to 304:
  * Performance and stability improvements
  * Change "Add disk" default behavior
  * Add SSH keys to VM creation dialog
  * Performance and stability improvements
* Fri Dec 15 2023 Dario Faggioli <dfaggioli@suse.com>
- Depend from a new meta-subpackage (qemu-spice) that the qemu
  package now makes available for everyone that needs all the qemu
  modules necessary for using SPICE (such as, us)
* Fri Sep  8 2023 Adam Majer <adam.majer@suse.de> - 298
- Update to 298:
  * bug and stability improvements
  * Don't use localhost as default source for PXE installation
- deps.patch: upstreamed, removed
* Mon Aug 21 2023 Adam Majer <adam.majer@suse.de>
- Update to 296:
  * Update to PatternFly 5
- deps.patch: fix esbuild dependency
* Thu Aug  3 2023 Adam Majer <adam.majer@suse.de>
- Update to 295
  * Performance and stability improvements
  * Bug fixes and translation updates
- 1088.patch: upstreamed and removed
* Fri Jun 16 2023 Adam Majer <adam.majer@suse.de>
- Update to 293
  * Add manifest condition for the Python bridge
  * Vsock device support
  * Apply watchdog changes on next boot if hotplug fails
  * Option to use RAW volume during VM creation
  * Redesign VM’s CPU configuration
  * Indicate need for shutdown
  * Delete storage file upon disk detachment
  * Show an alert when virtualization is disabled in BIOS/EFI
  * Create VM based on cloud image and start it later
  * Option to forcefully revert a snapshot
  * Support dark theme
  * Translation updates
  * Stability and performance updates
- 1088.patch: WIP for PF5 changes in cockpit
- hide-docs.patch, load-css-overrides.patch: refreshed
- suse-vv-install.patch: upstreamed, removed
* Fri Sep 23 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Require qemu-block-curl for installing over https (bsc#1199672)
* Wed Aug 10 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Require qemu USB drivers needed by virt-install (bsc#1202166)
* Fri Jun 17 2022 Adam Majer <adam.majer@suse.de>
- load-css-overrides.patch: css overrides for better theming support
* Mon Jun 13 2022 Adam Majer <adam.majer@suse.de>
- Update to 271.2:
  * Fix test/reference setup in release tarball for tests
* Fri Jun 10 2022 Adam Majer <adam.majer@suse.de>
- Update to 271.1:
  https://github.com/cockpit-project/cockpit-machines/releases/tag/270.1
* Thu May 19 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Add suse-vv-install.patch to display SUSE hint for virt-viewer
  installation (bsc#1199673)
* Thu Mar 17 2022 Adam Majer <adam.majer@suse.de>
- Update to 264:
  https://github.com/cockpit-project/cockpit-machines/releases/tag/264
* Mon Mar 14 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Hide links pointing to RHEL docs, hide-docs.patch (bsc#1197003)
* Thu Mar 10 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Require virt-install and qemu display drivers needed to start
  new VMs (bsc#1196971)
* Mon Jan 31 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Remove translate-toolkit which is not available in SLE
* Fri Jan 28 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Re-add source-offset to _service.
* Fri Aug 13 2021 Ludwig Nussel <lnussel@suse.de>
- new version 249.1
  https://github.com/cockpit-project/cockpit-machines/releases/tag/249
* Sun Jun 27 2021 ecsos <ecsos@opensuse.org>
- Add source-offest to _service to fix build error in Leap 15.3.
* Mon May  3 2021 Ludwig Nussel <lnussel@suse.de>
- initial package
